@@ -1,4 +1,11 @@
-# Time-stamp: <2016-02-12 00:11:11 Tao Liu>
+# Time-stamp: <2019-09-25 10:04:37 taoliu>
+
+"""Description: compare bdg files
+
+This code is free software; you can redistribute it and/or modify it
+under the terms of the BSD License (see the file LICENSE included with
+the distribution).
+"""
 
 import sys
 import os
@@ -84,6 +91,6 @@ def run( options ):
             raise Exception("Can't reach here!")
         
         info("Write bedGraph of scores...")
-        ofhd = open(ofile,"wb")
+        ofhd = open(ofile,"w")
         sbtrack.write_bedGraph(ofhd,name="%s_Scores" % (method.upper()),description="Scores calculated by %s" % (method.upper()), column = 3)
         info("Finished '%s'! Please check '%s'!" % (method, ofile))
