@@ -1,17 +1,10 @@
-# Time-stamp: <2018-10-16 12:06:22 Tao Liu>
+# Time-stamp: <2019-09-20 11:36:33 taoliu>
 
 """Description: Random sample certain number/percentage of tags.
 
-Copyright (c) 2011 Tao Liu <taoliu@jimmy.harvard.edu>
-
 This code is free software; you can redistribute it and/or modify it
-under the terms of the BSD License (see the file COPYING included
-with the distribution).
-
-@status: release candidate
-@version: $Id$
-@author:  Yong Zhang, Tao Liu
-@contact: taoliu@jimmy.harvard.edu
+under the terms of the BSD License (see the file LICENSE included with
+the distribution).
 """
 
 # ------------------------------------
@@ -88,7 +81,7 @@ def load_tag_files_options ( options ):
 
     """
     options.info("# read treatment tags...")
-    tp = options.parser(options.ifile[0])
+    tp = options.parser(options.ifile[0], buffer_size=options.buffer_size)
     if not options.tsize:           # override tsize if user specified --tsize
         ttsize = tp.tsize()
         options.tsize = ttsize
@@ -97,7 +90,7 @@ def load_tag_files_options ( options ):
     if len(options.ifile) > 1:
         # multiple input
         for ifile in options.ifile[1:]:
-            tp = options.parser(ifile)
+            tp = options.parser(ifile, buffer_size=options.buffer_size)
             treat = tp.append_fwtrack( treat )
             #treat.sort()
     treat.finalize()
@@ -111,13 +104,13 @@ def load_frag_files_options ( options ):
     """
     options.info("# read treatment fragments...")
 
-    tp = options.parser(options.ifile[0])
+    tp = options.parser(options.ifile[0], buffer_size=options.buffer_size)
     treat = tp.build_petrack()
     #treat.sort()
     if len(options.ifile) > 1:
         # multiple input
         for ifile in options.ifile[1:]:
-            tp = options.parser(ifile)
+            tp = options.parser(ifile, buffer_size=options.buffer_size)
             treat = tp.append_petrack( treat )
             #treat.sort()
     treat.finalize()
